<?php

namespace WilokeFeaturedProducts\Shared;

use WP_Post;

class HtmlHelper
{
	public static function autoPrefix($item)
	{
		return strpos($item, WILOKE_FEATURED_PRODUCTS_ID) === false ? WILOKE_FEATURED_PRODUCTS_ID . '-' . $item : $item;
	}

	public static function generateExcerptLength(WP_Post $post, int $length, string $appendix = '...'): string
	{
		$string = $post->post_content;
		// Check if mb_strlen and mb_substr functions are available.
		$mbAvailable = function_exists('mb_strlen') && function_exists('mb_substr');

		$strLength = $mbAvailable ? mb_strlen($string) : strlen($string);

		if ($strLength <= $length) {
			return $string;
		}

		// Subtract the length of the appendix to ensure the final string doesn't exceed the desired length.
		$substrFunc = $mbAvailable ? 'mb_substr' : 'substr';
		return $substrFunc($string, 0, $length - ($mbAvailable ? mb_strlen($appendix) : strlen($appendix))) . $appendix;
	}

	public static function renderItem(WP_Post $post, array $aSettings = [])
	{
		$thumbnailUrl = get_the_post_thumbnail_url($post->ID, "large");
		$product = wc_get_product($post->ID);
		?>
		<div class="swiper-slide" style="--gradient-bg-url: url(<?php echo esc_url($thumbnailUrl); ?>);">
			<?php
			if ($product->is_on_sale()) {
				?>
				<span class="wiloke-featured-products-badge on-sale"
				      style="--badge-color: <?php echo esc_attr($aSettings["badge_color"]); ?>; --badge-bg-color: <?php echo
				      esc_attr($aSettings["badge_bg_color"]); ?>;"><?php esc_html_e("On sale",
						"wiloke-featured-products"); ?></span>
				<?php
			}
			?>

			<div class="slide-content">
				<h3 class="wiloke-featured-products-title" style="--price-color: <?php echo esc_attr($aSettings["title_color"]); ?>">
					<a href="<?php echo esc_url(get_permalink($post)); ?>"><?php echo esc_html(get_the_title($post)); ?></a>
				</h3>
				<div class="wiloke-featured-products-price">
					<?php
					if ($product->is_on_sale()) {
						?>
						<span class="wiloke-featured-products-price wiloke-featured-products-regular-price"
						      style="--price-color: <?php echo esc_attr($aSettings["regular_price_color"]); ?>"
						><del><?php echo wc_price($product->get_regular_price()); ?></del></span>
						<span class="wiloke-featured-products-price wiloke-featured-products-sale-price"
						      style="--price-color: <?php echo esc_attr($aSettings["on_sale_price_color"]); ?>"><?php echo wc_price($product->get_sale_price()); ?></span>
						<?php
					} else {
						?>
						<span class="wiloke-featured-products-price wiloke-featured-products-price"
						      style="--price-color: <?php echo esc_attr($aSettings["price_color"]); ?>"><?php echo wc_price($product->get_regular_price()); ?></span>
						<?php
					}
					?>
				</div>
			</div>
		</div>
		<?php
	}
}
