<?php

namespace WilokeFeaturedProducts\Widgets;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use WC_Product_Query;
use WilokeFeaturedProducts\Shared\HtmlHelper;
use WP_Query;

class FeaturedProductsWidget extends Widget_Base
{

	public function get_style_depends()
	{
		return ["swiper", WILOKE_FEATURED_PRODUCTS_ID];
	}

	public function get_script_depends()
	{
		return ["swiper", WILOKE_FEATURED_PRODUCTS_ID];
	}

	public function get_name()
	{
		return WILOKE_FEATURED_PRODUCTS_ID . '-settings';
	}

	public function get_title()
	{
		return "Wiloke Featured Products";
	}

	/**
	 * https://elementor.github.io/elementor-icons/
	 * @return string
	 */
	public function get_icon()
	{
		return 'eicon-slider-push';
	}

	public function get_categories()
	{
		return ['wiloke-category'];
	}

	protected function getOptions(): array
	{
		$aPostTypes = get_post_types([
			'public' => true
		], 'objects');

		$aOptions = [
			"---" => esc_html__("Select a category", "wiloke-featured-products")
		];

		foreach ($aPostTypes as $oPostType) {
			if (in_array($oPostType->name, ["attachment", "elementor_library"])) {
				continue;
			}
			$aOptions[$oPostType->name] = $oPostType->labels->singular_name;
		}

		return $aOptions;
	}

	protected function _register_controls()
	{
		$this->start_controls_section(
			'wiloke_posts_slider_section_content',
			[
				'label' => esc_html__("Settings", "wiloke-featured-products"),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			"heading",
			[
				"label"   => esc_html__("Heading", "wiloke-featured-products"),
				"type"    => Controls_Manager::TEXT,
				"default" => "The best Selling products"
			]
		);

		$this->add_control(
			"description",
			[
				"label"   => esc_html__("Description", "wiloke-featured-products"),
				"type"    => Controls_Manager::WYSIWYG,
				"default" => "Lorem, ipsum dolor sit amet consectetur adipisicing elit. Repudiandae quam magnam obcaecati error consequatur repellat fugiat, deleniti nisi eum voluptates."
			]
		);


		$this->add_control(
			"button_name",
			[
				"label"   => esc_html__("Button Name", "wiloke-featured-products"),
				"type"    => Controls_Manager::TEXT,
				"default" => "Go to Collections"
			]
		);

		$this->add_control(
			"button_link",
			[
				"label" => esc_html__("Button Link", "wiloke-featured-products"),
				"type"  => Controls_Manager::URL
			]
		);

		$this->add_control(
			"ids",
			[
				"label"       => esc_html__("Specified Ids", "wiloke-featured-products"),
				"description" => esc_html__("Enter the ids of the categories you want to display. Separate by commas.",
					"wiloke-featured-products"),
				"type"        => Controls_Manager::TEXT
			]
		);


		$this->add_control(
			"posts_per_page",
			[
				"label"   => esc_html__("Max Items", "wiloke-featured-products"),
				"type"    => Controls_Manager::NUMBER,
				"default" => 6,
				"min"     => 1,
				"max"     => 15
			]
		);

		$this->add_control(
			"orderby",
			[
				"label"   => esc_html__("Order By", "wiloke-featured-products"),
				"type"    => Controls_Manager::SELECT,
				"default" => "date",
				"options" => [
					"popularity" => esc_html__("Popularity", "wiloke-featured-products"),
					"rating"     => esc_html__("Rating", "wiloke-featured-products"),
					"price"      => esc_html__("Price", "wiloke-featured-products"),
					"menu_order" => esc_html__("Menu Order", "wiloke-featured-products"),
					"rand"       => esc_html__("Random", "wiloke-featured-products"),
					"id"         => esc_html__("Id", "wiloke-featured-products"),
					"title"      => esc_html__("Title", "wiloke-featured-products"),
					"post__in"   => esc_html__("Exactly ids entered above", "wiloke-featured-products"),
				]
			]
		);
		$this->add_control(
			"order",
			[
				"label"   => esc_html__("Order", "wiloke-featured-products"),
				"type"    => Controls_Manager::SELECT,
				"default" => "DESC",
				"options" => [
					"DESC" => esc_html__("DESC", "wiloke-featured-products"),
					"ASC"  => esc_html__("ASC", "wiloke-featured-products")
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'wiloke_posts_slider_style_settings',
			[
				'label' => esc_html__('Extra Settings', "wiloke-featured-products"),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'autoplaydelay',
			[
				'label'   => esc_html__('Auto play delays (mini seconds)', "wiloke-featured-products"),
				'type'    => Controls_Manager::NUMBER,
				"default" => 5000
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'   => esc_html__('Product Title Color', "wiloke-featured-products"),
				'type'    => Controls_Manager::COLOR,
				"default" => "#fff"
			]
		);

		$this->add_control(
			'badge_color',
			[
				'label'   => esc_html__('Product Badge Color', "wiloke-featured-products"),
				'type'    => Controls_Manager::COLOR,
				"default" => "#fff"
			]
		);

		$this->add_control(
			'badge_bg_color',
			[
				'label'   => esc_html__('Product Badge Background Color', "wiloke-featured-products"),
				'type'    => Controls_Manager::COLOR,
				"default" => "#9926e1"
			]
		);


		$this->add_control(
			'price_color',
			[
				'label'   => esc_html__('Product Price Color', "wiloke-featured-products"),
				'type'    => Controls_Manager::COLOR,
				"default" => "#fff"
			]
		);

		$this->add_control(
			'regular_price_color',
			[
				'label'   => esc_html__('Product Regular Price Color', "wiloke-featured-products"),
				'type'    => Controls_Manager::COLOR,
				"default" => "#000"
			]
		);

		$this->add_control(
			'on_sale_price_color',
			[
				'label'   => esc_html__('Product Sale Price Color', "wiloke-featured-products"),
				'type'    => Controls_Manager::COLOR,
				"default" => "#fff"
			]
		);

		$this->add_control(
			"button_color",
			[
				"label"   => esc_html__("Button Color", "wiloke-featured-products"),
				"type"    => Controls_Manager::COLOR,
				"default" => "#fff"
			]
		);

		$this->add_control(
			"heading_color",
			[
				"label"   => esc_html__("Heading Color", "wiloke-featured-products"),
				"type"    => Controls_Manager::COLOR,
				"default" => "#fff"
			]
		);

		$this->add_control(
			"description_color",
			[
				"label"   => esc_html__("Description Color", "wiloke-featured-products"),
				"type"    => Controls_Manager::COLOR,
				"default" => "#fff"
			]
		);


		$this->add_control(
			"button_bg_color",
			[
				"label"   => esc_html__("Button Background Color", "wiloke-featured-products"),
				"type"    => Controls_Manager::COLOR,
				"default" => "#d51a6d"
			]
		);

		$this->end_controls_section();
	}

	protected function render()
	{
		$aSettings = $this->get_settings_for_display();

		if (empty($aSettings)) {
			return;
		}
		$aArgs = [
			"post_status"    => "publish",
			"posts_per_page" => $aSettings["posts_per_page"],
			"post_type"      => "product",
			"orderby"        => $aSettings["orderby"],
			"order"          => $aSettings["order"]
		];

		if (!empty($aSettings["ids"])) {
			$aArgs["post__in"] = explode(",", $aSettings["ids"]);
			$aArgs["posts_per_page"] = count($aArgs["post__in"]);
		}

		if ($aArgs["orderby"] == "popularity") {
			$aArgs["meta_key"] = "total_sales";
			$aArgs["orderby"] = "meta_value_num";
			$aArgs["order"] = "DESC";
		} else if ($aArgs["orderby"] == "rating") {
			$aArgs["meta_key"] = "rating";
			$aArgs["orderby"] = "meta_value_num";
			$aArgs["order"] = "DESC";
		} else if ($aArgs["orderby"] == "price"){
			$aArgs["meta_key"] = "_price";
			$aArgs["orderby"] = "meta_value_num";
			$aArgs["order"] = "DESC";
		}

		$query = new WP_Query($aArgs);
		if (!$query->have_posts()) {
			wp_reset_postdata();
			return;
		}

		$btnLink = $aSettings["button_link"]["url"] ?? "";
		$btnTarget = $aSettings["button_link"]["is_external"] ? "_blank" : "_self";
		$btnName = $aSettings["button_name"] ?? esc_html__("Go to Collections", "wiloke-featured-products");
		?>

		<div class="wiloke-featured-products-wrapper">
			<div class="wiloke-featured-products-content">
				<h2 class="wiloke-featured-products-heading"
				    style="--heading-color: <?php echo esc_attr($aSettings["heading_color"]); ?>"><?php echo
					esc_html($aSettings["heading"]); ?></h2>
				<p class="wiloke-featured-products-sub-heading"  style="--description-color: <?php echo esc_attr($aSettings["description_color"]); ?>"><?php echo wp_kses_post($aSettings["description"]); ?></p>
				<?php ?>
				<?php if (!empty($btnLink)): ?>
					<a class="wiloke-featured-products-btn"
					   href="<?php echo esc_url($btnLink); ?>"
					   style="--button-color: <?php echo esc_attr($aSettings["button_color"]); ?>; --button-bg-color: <?php echo esc_attr($aSettings["button_bg_color"]); ?>;"
					   target="<?php echo esc_url($btnTarget); ?>">
						<?php echo esc_html($btnName); ?>
						<i class="eicon-arrow-right"></i>
					</a>
				<?php endif; ?>
			</div>

			<div class="swiper-container">
				<div class="wiloke-featured-product-swiper swiper"  data-swiper-autoplay="<?php echo esc_attr($aSettings["autoplaydelay"]); ?>">
					<div class="swiper-wrapper">
						<?php
						while ($query->have_posts()) {
							$query->the_post();
							HtmlHelper::renderItem($query->post, $aSettings);
							$aSettings["order"] = $aSettings["order"] + 1;
						}

						wp_reset_postdata();
						?>
					</div>
				</div>
				<div class="swiper-pagination"></div>
			</div>

			<div class="circle"></div>
		</div>
		<?php
	}
}
